@@ -240,6 +240,7 @@
 		hEst = mvar
 	} else{
 		ipars[idx["omega",1],1] = mvar * (1 - persist) - mv
+		hEst = mvar
 	}
 	if(is.na(hEst) | !is.finite(hEst) | is.nan(hEst)) hEst = var(data)
 	assign("ipars", ipars, envir = garchenv)
@@ -425,7 +426,7 @@
 			mean.model = list(armaOrder = c(modelinc[2], modelinc[3]),
 					include.mean = modelinc[1], 
 					archm = ifelse(modelinc[5]>0,TRUE,FALSE), archpow = modelinc[5], arfima = modelinc[4], 
-					external.regressors = mxf[1:(N + fcreq), , drop = FALSE]), 
+					external.regressors = mxf[1:(N + fcreq), , drop = FALSE], archex = modelinc[20]), 
 			distribution.model = model$modeldesc$distribution, fixed.pars = as.list(pars))
 	tmp =  data.frame(data[1:(N + fcreq)])
 	rownames(tmp) = as.character(dates[1:(N + fcreq)])
@@ -567,7 +568,7 @@
 			mean.model = list(armaOrder = c(modelinc[2], modelinc[3]),
 					include.mean = modelinc[1], 
 					archm = ifelse(modelinc[5]>0,TRUE,FALSE), archpow = modelinc[5], arfima = modelinc[4], 
-					external.regressors = mxf[1:(N + fcreq), , drop = FALSE]), 
+					external.regressors = mxf[1:(N + fcreq), , drop = FALSE], archex = modelinc[20]), 
 			distribution.model = model$modeldesc$distribution, fixed.pars = as.list(pars))
 	tmp =  data.frame(data[1:(N + fcreq)])
 	rownames(tmp) = as.character(dates[1:(N + fcreq)])
@@ -677,8 +678,7 @@
 	kappa = egarchKappa(ipars[idx["ghlambda",1],1], ipars[idx["shape",1],1], ipars[idx["skew",1],1], distribution)
 	if(N < n.start){
 		startmethod[1] = "unconditional"
-		cat("\nugarchsim-->warning: n.start greater than length of data...using unconditional 
-						start method...\n")
+		warning("\nugarchsim-->warning: n.start greater than length of data...using unconditional start method...\n")
 	}
 	
 	# Random Samples from the Distribution
@@ -757,7 +757,16 @@
 		residSim[,i] = ans1$res[(n.start + m + 1):(n+m)]
 		if(modelinc[6]>0){
 			mxreg = matrix( ipars[idx["mxreg",1]:idx["mxreg",2], 1], ncol = modelinc[6] )
-			constm[,i] = constm[,i] + mxreg %*%t( matrix( mexsim[[i]], ncol = modelinc[6] ) )
+			if(modelinc[20]==0){
+				constm[,i] = constm[,i] + mxreg %*%t( matrix( mexsim[[i]], ncol = modelinc[6] ) )
+			} else{
+				if(modelinc[20] == modelinc[6]){
+					constm[,i] = constm[,i] + mxreg %*%t( matrix( mexsim[[i]]*sqrt(ans1$h), ncol = modelinc[6] ) )
+				} else{
+					constm[,i] = constm[,i] + mxreg[,1:(modelinc[6]-modelinc[20]),drop=FALSE] %*%t( matrix( mexsim[[i]][,1:(modelinc[6]-modelinc[20]),drop=FALSE], ncol = modelinc[6]-modelinc[20] ) )
+					constm[,i] = constm[,i] + mxreg[,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE] %*%t( matrix( mexsim[[i]][,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE]*sqrt(ans1$h), ncol = modelinc[20] ) )
+				}
+			}
 		}
 		
 		if(modelinc[5]>0) constm[,i] = constm[,i] + ipars[idx["archm",1]:idx["archm",2], 1]*(sqrt(ans1$h)^modelinc[5])
@@ -814,8 +823,7 @@
 	
 	if(N < n.start){
 		startmethod[1] = "unconditional"
-		cat("\nugarchsim-->warning: n.start greater than length of data...using unconditional 
-						start method...\n")
+		warning("\nugarchsim-->warning: n.start greater than length of data...using unconditional start method...\n")
 	}
 	
 	# Random Samples from the Distribution
@@ -900,7 +908,16 @@
 	
 	if(modelinc[6]>0){
 		mxreg = matrix( ipars[idx["mxreg",1]:idx["mxreg",2], 1], ncol = modelinc[6] )
-		mxs = sapply(mexsim, FUN = function(x) mxreg%*%t(matrix(x, ncol = modelinc[6])))
+		if(modelinc[20]==0){
+			mxs = sapply(mexsim, FUN = function(x) mxreg%*%t(matrix(x, ncol = modelinc[6])))
+		} else{
+			if(modelinc[20] == modelinc[6]){
+				mxs = sapply(mexsim, FUN = function(x) mxreg%*%t(matrix(x*sqrt(ans$h), ncol = modelinc[6])))
+			} else{
+				mxs = sapply(mexsim, FUN = function(x) mxreg[,1:(modelinc[6]-modelinc[20]),drop=FALSE]%*%t(matrix(x[,1:(modelinc[6]-modelinc[20]),drop=FALSE], ncol = modelinc[6])))
+				mxs = mxs + sapply(mexsim, FUN = function(x) mxreg[,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE]%*%t(matrix(x[,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE]*sqrt(ans$h), ncol = modelinc[20])))				
+			}
+		}
 	} else{
 		mxs = 0
 	}
@@ -1071,7 +1088,16 @@
 		residSim[,i] = ans1$res[(n.start + m + 1):(n+m)]
 		if(modelinc[6]>0){
 			mxreg = matrix( ipars[idx["mxreg",1]:idx["mxreg",2], 1], ncol = modelinc[6] )
-			constm[,i] = constm[,i] + mxreg %*%t( matrix( mexsim[[i]], ncol = modelinc[6] ) )
+			if(modelinc[20]==0){
+				constm[,i] = constm[,i] + as.numeric( mxreg %*%t( matrix( mexsim[[i]], ncol = modelinc[6] ) ) )
+			} else{
+				if(modelinc[20] == modelinc[6]){
+					constm[,i] = constm[,i] + as.numeric( mxreg %*%t( matrix( mexsim[[i]]*sqrt(ans1$h), ncol = modelinc[6] ) ) )
+				} else{
+					constm[,i] = constm[,i] + as.numeric( mxreg[,1:(modelinc[6]-modelinc[20]),drop=FALSE] %*%t( matrix( mexsim[[i]][,1:(modelinc[6]-modelinc[20]),drop=FALSE], ncol = modelinc[6]-modelinc[20] ) ) )
+					constm[,i] = constm[,i] + as.numeric( mxreg[,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE] %*%t( matrix( mexsim[[i]][,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE]*sqrt(ans1$h), ncol = modelinc[20] ) ) )
+				}
+			}
 		}
 		if(modelinc[5]>0) constm[,i] = constm[,i] + ipars[idx["archm",1]:idx["archm",2], 1]*(sqrt(ans1$h)^modelinc[5])
 		if(modelinc[4]>0){
@@ -1217,7 +1243,16 @@
 	
 	if(modelinc[6]>0){
 		mxreg = matrix( ipars[idx["mxreg",1]:idx["mxreg",2], 1], ncol = modelinc[6] )
-		mxs = sapply(mexsim, FUN = function(x) mxreg%*%t(matrix(x, ncol = modelinc[6])))
+		if(modelinc[20]==0){
+			mxs = sapply(mexsim, FUN = function(x) mxreg%*%t(matrix(x, ncol = modelinc[6])))
+		} else{
+			if(modelinc[20] == modelinc[6]){
+				mxs = sapply(mexsim, FUN = function(x) mxreg%*%t(matrix(x*sqrt( ans$h ), ncol = modelinc[6])))
+			} else{
+				mxs = sapply(mexsim, FUN = function(x) mxreg[,1:(modelinc[6]-modelinc[20]),drop=FALSE]%*%t(matrix(x[,1:(modelinc[6]-modelinc[20]),drop=FALSE], ncol = modelinc[6])))
+				mxs = mxs + sapply(mexsim, FUN = function(x) mxreg[,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE]%*%t(matrix(x[,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE]*sqrt( ans$h ), ncol = modelinc[20])))				
+			}
+		}
 	} else{
 		mxs = 0
 	}
