@@ -91,8 +91,7 @@
 			if(fit.control$fixed.se==0) {
 				# if all parameters are fixed an no standard erros are to
 				# be calculated then we return a ugarchfilter object
-				cat("\nugarchfit-->warning: all parameters fixed...returning ugarchfilter 
-object instead\n")
+				warning("\nugarchfit-->warning: all parameters fixed...returning ugarchfilter object instead\n")
 				return(ugarchfilter(data = data, spec = spec, out.sample = out.sample))
 			} else{
 				# if all parameters are fixed but we require standard errors, we
@@ -198,6 +197,7 @@ object instead\n")
 	# will be called by other functions (show, plot, sim etc)
 	model = model
 	model$n.start = n.start
+	fit$solver = solution
 	ans = new("uGARCHfit",
 			fit = fit,
 			model = model)
@@ -455,7 +455,7 @@ object instead\n")
 			mean.model = list(armaOrder = c(modelinc[2], modelinc[3]),
 					include.mean = modelinc[1], 
 					archm = ifelse(modelinc[5]>0,TRUE,FALSE), archpow = modelinc[5], arfima = modelinc[4], 
-					external.regressors = mxf[1:(N + fcreq), , drop = FALSE]), 
+					external.regressors = mxf[1:(N + fcreq), , drop = FALSE], archex = modelinc[20]), 
 			distribution.model = model$modeldesc$distribution, fixed.pars = as.list(pars))
 	tmp =  data.frame(data[1:(N + fcreq)])
 	rownames(tmp) = as.character(dates[1:(N + fcreq)])
@@ -597,7 +597,7 @@ object instead\n")
 			mean.model = list(armaOrder = c(modelinc[2], modelinc[3]),
 					include.mean = modelinc[1], 
 					archm = ifelse(modelinc[5]>0,TRUE,FALSE), archpow = modelinc[5], arfima = modelinc[4], 
-					external.regressors = mxf[1:(N + fcreq), , drop = FALSE]), 
+					external.regressors = mxf[1:(N + fcreq), , drop = FALSE], archex = modelinc[20]),
 			distribution.model = model$modeldesc$distribution, fixed.pars = as.list(pars))
 	tmp =  data.frame(data[1:(N + fcreq)])
 	rownames(tmp) = as.character(dates[1:(N + fcreq)])
@@ -704,8 +704,7 @@ object instead\n")
 	
 	if(N < n.start){
 		startmethod[1] = "unconditional"
-		cat("\nugarchsim-->warning: n.start greater than length of data...using unconditional 
-						start method...\n")
+		warning("\nugarchsim-->warning: n.start greater than length of data...using unconditional start method...\n")
 	}
 	
 	# Random Samples from the Distribution
@@ -785,11 +784,20 @@ object instead\n")
 		
 		sigmaSim[,i] = ans1$h[(n.start + m + 1):(n+m)]^(1/2)
 		residSim[,i] = ans1$res[(n.start + m + 1):(n+m)]
+		# ToDo: change to accomodate modelinc[20]
 		if(modelinc[6]>0){
 			mxreg = matrix( ipars[idx["mxreg",1]:idx["mxreg",2], 1], ncol = modelinc[6] )
-			constm[,i] = constm[,i] + mxreg %*%t( matrix( mexsim[[i]], ncol = modelinc[6] ) )
+			if(modelinc[20]==0){
+				constm[,i] = constm[,i] + mxreg %*%t( matrix( mexsim[[i]], ncol = modelinc[6] ) )
+			} else{
+				if(modelinc[20] == modelinc[6]){
+					constm[,i] = constm[,i] + mxreg %*%t( matrix( mexsim[[i]]*sqrt(ans1$h), ncol = modelinc[6] ) )
+				} else{
+					constm[,i] = constm[,i] + mxreg[,1:(modelinc[6]-modelinc[20]),drop=FALSE] %*%t( matrix( mexsim[[i]][,1:(modelinc[6]-modelinc[20]),drop=FALSE], ncol = modelinc[6]-modelinc[20] ) )
+					constm[,i] = constm[,i] + mxreg[,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE] %*%t( matrix( mexsim[[i]][,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE]*sqrt(ans1$h), ncol = modelinc[20] ) )
+				}
+			}
 		}
-		
 		if(modelinc[5]>0) constm[,i] = constm[,i] + ipars[idx["archm",1]:idx["archm",2], 1]*(sqrt(ans1$h)^modelinc[5])
 		
 		if(modelinc[4]>0){
@@ -840,8 +848,7 @@ object instead\n")
 	
 	if(N < n.start){
 		startmethod[1] = "unconditional"
-		cat("\nugarchsim-->warning: n.start greater than length of data...using unconditional 
-						start method...\n")
+		warning("\nugarchsim-->warning: n.start greater than length of data...using unconditional start method...\n")
 	}
 	
 	# Random Samples from the Distribution
@@ -926,9 +933,19 @@ object instead\n")
 	sigmaSim = matrix(sqrt( ans$h[(n.start + m + 1):(n+m), ] ), ncol = m.sim)
 	residSim = matrix(ans$res[(n.start + m + 1):(n+m), ], ncol = m.sim)
 	
+	
 	if(modelinc[6]>0){
 		mxreg = matrix( ipars[idx["mxreg",1]:idx["mxreg",2], 1], ncol = modelinc[6] )
-		mxs = sapply(mexsim, FUN = function(x) mxreg%*%t(matrix(x, ncol = modelinc[6])))
+		if(modelinc[20]==0){
+			mxs = sapply(mexsim, FUN = function(x) mxreg%*%t(matrix(x, ncol = modelinc[6])))
+		} else{
+			if(modelinc[20] == modelinc[6]){
+				mxs = sapply(mexsim, FUN = function(x) mxreg%*%t(matrix(x*sqrt(ans$h), ncol = modelinc[6])))
+			} else{
+				mxs = sapply(mexsim, FUN = function(x) mxreg[,1:(modelinc[6]-modelinc[20]),drop=FALSE]%*%t(matrix(x[,1:(modelinc[6]-modelinc[20]),drop=FALSE], ncol = modelinc[6])))
+				mxs = mxs + sapply(mexsim, FUN = function(x) mxreg[,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE]%*%t(matrix(x[,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE]*sqrt(ans$h), ncol = modelinc[20])))				
+			}
+		}
 	} else{
 		mxs = 0
 	}
@@ -1099,7 +1116,16 @@ object instead\n")
 		residSim[,i] = ans1$res[(n.start + m + 1):(n+m)]
 		if(modelinc[6]>0){
 			mxreg = matrix( ipars[idx["mxreg",1]:idx["mxreg",2], 1], ncol = modelinc[6] )
-			constm[,i] = constm[,i] + mxreg %*%t( matrix( mexsim[[i]], ncol = modelinc[6] ) )
+			if(modelinc[20]==0){
+				constm[,i] = constm[,i] + as.numeric( mxreg %*%t( matrix( mexsim[[i]], ncol = modelinc[6] ) ) )
+			} else{
+				if(modelinc[20] == modelinc[6]){
+					constm[,i] = constm[,i] + as.numeric( mxreg %*%t( matrix( mexsim[[i]]*sqrt(ans1$h), ncol = modelinc[6] ) ) )
+				} else{
+					constm[,i] = constm[,i] + as.numeric( mxreg[,1:(modelinc[6]-modelinc[20]),drop=FALSE] %*%t( matrix( mexsim[[i]][,1:(modelinc[6]-modelinc[20]),drop=FALSE], ncol = modelinc[6]-modelinc[20] ) ) )
+					constm[,i] = constm[,i] + as.numeric( mxreg[,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE] %*%t( matrix( mexsim[[i]][,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE]*sqrt(ans1$h), ncol = modelinc[20] ) ) )
+				}
+			}
 		}
 		if(modelinc[5]>0) constm[,i] = constm[,i] + ipars[idx["archm",1]:idx["archm",2], 1]*(sqrt(ans1$h)^modelinc[5])
 		if(modelinc[4]>0){
@@ -1245,7 +1271,16 @@ object instead\n")
 	
 	if(modelinc[6]>0){
 		mxreg = matrix( ipars[idx["mxreg",1]:idx["mxreg",2], 1], ncol = modelinc[6] )
-		mxs = sapply(mexsim, FUN = function(x) mxreg%*%t(matrix(x, ncol = modelinc[6])))
+		if(modelinc[20]==0){
+			mxs = sapply(mexsim, FUN = function(x) mxreg%*%t(matrix(x, ncol = modelinc[6])))
+		} else{
+			if(modelinc[20] == modelinc[6]){
+				mxs = sapply(mexsim, FUN = function(x) mxreg%*%t(matrix(x*sqrt( ans$h ), ncol = modelinc[6])))
+			} else{
+				mxs = sapply(mexsim, FUN = function(x) mxreg[,1:(modelinc[6]-modelinc[20]),drop=FALSE]%*%t(matrix(x[,1:(modelinc[6]-modelinc[20]),drop=FALSE], ncol = modelinc[6])))
+				mxs = mxs + sapply(mexsim, FUN = function(x) mxreg[,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE]%*%t(matrix(x[,(modelinc[6]-modelinc[20]+1):modelinc[6],drop=FALSE]*sqrt( ans$h ), ncol = modelinc[20])))				
+			}
+		}
 	} else{
 		mxs = 0
 	}
